@@ -35,6 +35,7 @@
 #include "gyrus-session.h"
 #include "gyrus-preferences.h"
 #include "gyrus-admin-mailbox.h"
+#include "gyrus-report.h"
 
 static void gyrus_main_app_class_init (GyrusMainAppClass *class);
 static void gyrus_main_app_init (GyrusMainApp *app);
@@ -193,6 +194,17 @@ gyrus_main_app_on_view_refresh (BonoboUIComponent *component,
 	gyrus_admin_refresh_users_list (admin);
 }
 
+static void
+gyrus_main_app_on_view_report (BonoboUIComponent *component,
+			       gpointer user_data,
+			       const char *cname)
+{
+	GyrusMainApp *app  = GYRUS_MAIN_APP (user_data);
+	GyrusAdmin *admin = gyrus_main_app_get_current_admin (app);
+
+	gyrus_report_show_report(admin);
+}
+
 static void
 gyrus_main_app_on_help_about (BonoboUIComponent *component,
 				     gpointer user_data,
@@ -261,6 +273,9 @@ gyrus_main_app_on_button_close_page_clicked (GtkButton *button, gpointer data)
 				  (app->priv->notebook), page_number);
 
 	gyrus_main_app_make_sensitivity_consistent (app);
+	
+	if (gtk_notebook_get_n_pages (GTK_NOTEBOOK (app->priv->notebook)) == 0)
+		gtk_window_set_title (GTK_WINDOW (app), _("Cyrus IMAP Administrator"));
 }
 
 void
@@ -275,6 +290,12 @@ gyrus_main_app_on_switch_page (GtkNotebook *notebook,
 	GyrusAdmin *admin = GYRUS_ADMIN (gtk_notebook_get_nth_page (notebook,
 								    page_num));
 	
+	const gchar *session_name = gyrus_admin_get_current_session_name (admin);
+	gchar *title = g_strdup_printf (_("%s - Cyrus IMAP Administrator"), 
+					session_name);
+	gtk_window_set_title (GTK_WINDOW (app), title);
+	g_free (title);
+
 	gchar *mailbox;
 	if (gyrus_admin_is_connected (admin))
 		gyrus_main_app_menu_set_sensitive (app, TRUE);
@@ -359,6 +380,7 @@ static const BonoboUIVerb gyrus_main_app_verbs [] = {
 	BONOBO_UI_VERB ("AclEntryRename",  gyrus_main_app_on_acl_entry_rename),
 	BONOBO_UI_VERB ("AclEntryDelete",  gyrus_main_app_on_acl_entry_delete),
 	BONOBO_UI_VERB ("ViewRefresh",     gyrus_main_app_on_view_refresh),
+	BONOBO_UI_VERB ("ViewReport",      gyrus_main_app_on_view_report),
 	BONOBO_UI_VERB ("HelpAbout",       gyrus_main_app_on_help_about),
 	
 	BONOBO_UI_VERB_END
@@ -451,7 +473,6 @@ gyrus_main_app_get_current_admin (GyrusMainApp *app)
 static void
 gyrus_main_app_about (void)
 {
-	static GtkWidget *about_box = NULL;
 	GdkPixbuf *pixbuf;
 	gchar *logo_gyrus;
 
@@ -466,12 +487,7 @@ gyrus_main_app_about (void)
 
 	const gchar *documentors[] = { NULL };
 
-	const gchar *translators = _("translators");
-
-	if (about_box != NULL){
-		gtk_window_present(GTK_WINDOW(about_box));
-		return;
-	}
+	const gchar *translators = _("translators-credits");
 
 	logo_gyrus = g_strdup_printf ("%s%c%s", GYRUS_PIXMAPS_DIR,
 	                              G_DIR_SEPARATOR, "logo_gyrus.png");
@@ -479,19 +495,18 @@ gyrus_main_app_about (void)
 	pixbuf = gdk_pixbuf_new_from_file(logo_gyrus, NULL);
 	
 	g_free (logo_gyrus);
-
-	about_box = gnome_about_new (_("GNOME Cyrus Administrator"),
-				     VERSION,
-				     _("(c) 2003 GNOME Foundation"),
-				     _("Administration tool for Cyrus IMAP servers."),
-				     authors, documentors,
-				     strcmp (translators, "translators") != 0 ? translators : NULL,
-				     pixbuf);
-
-	g_signal_connect (G_OBJECT(about_box), "destroy",
-			  G_CALLBACK(gtk_widget_destroyed), &about_box);
 	
-	gtk_widget_show(about_box);
+	gtk_show_about_dialog (NULL,
+			       "name", _("GNOME Cyrus Administrator"),
+			       "version", VERSION,
+			       "copyright", _("(c) 2003-2005 GNOME Foundation\n"
+					      "(c) 2004-2005 Claudio Saavedra"),
+			       "comments", _("Administration tool for Cyrus IMAP servers."),
+			       "authors", authors, 
+			       "documenters", documentors,
+			       "translator-credits", strcmp (translators, "translators-credits") != 0 ? translators : NULL,
+			       "logo", pixbuf,
+			       NULL);
 
 	g_object_unref(pixbuf);
 }
@@ -601,6 +616,8 @@ gyrus_main_app_menu_set_sensitive (GyrusMainApp *app, gboolean sens)
 		(app, "/commands/EditMailboxAdd", sens);
 	gyrus_main_app_menu_item_set_sensitive
 		(app, "/commands/ViewRefresh", sens);
+	gyrus_main_app_menu_item_set_sensitive
+                (app, "/commands/ViewReport", sens);
 }
 
 /***** Above functions doesnt belong this file ******/
@@ -618,6 +635,7 @@ main (int argc, char *argv[])
 	GtkWidget *app;
 	gtk_init (&argc, &argv);
 	bindtextdomain (GETTEXT_PACKAGE, GNOME_LOCALE_DIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
 	gnome_program_init ("gyrus", VERSION, LIBGNOMEUI_MODULE,
